@@ -9,6 +9,6 @@ import sys
 acts_path, act_name = os.path.split(os.path.dirname(os.path.abspath(__file__)))
 
 sys.path.insert(0,acts_path)
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "%s.act_settings" % (act_name))
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "%s.settings" % (act_name))
 from django.core.wsgi import get_wsgi_application
 application=get_wsgi_application()
